@@ -42,14 +42,15 @@ class Database:
             self._children = self.client.get_database_pages(self.notion_id)
         return self._children
 
+    def get_children(self):
+        self._children = self.client.get_database_pages(self.notion_id)
+
     def children_filtered(self, filter, sort=None):
         if not filter:
             return self.children
         else:
             tupled_filter = self._tuplize(filter)
             tupled_sort = self._tuplize(sort)
-            print(tupled_filter)
-            print(tupled_sort)
             if tupled_filter not in self._filtered_children:
                 self._filtered_children[tupled_filter] = {}
             if tupled_sort not in self._filtered_children[tupled_filter]:
